@@ -32,7 +32,7 @@
  *
  * Since: 2017.4
  */
-#define OSTREE_YEAR_VERSION (2022)
+#define OSTREE_YEAR_VERSION (2023)
 
 /**
  * OSTREE_RELEASE_VERSION:
@@ -41,7 +41,7 @@
  *
  * Since: 2017.4
  */
-#define OSTREE_RELEASE_VERSION (7)
+#define OSTREE_RELEASE_VERSION (6)
 
 /**
  * OSTREE_VERSION
@@ -50,7 +50,7 @@
  *
  * Since: 2017.4
  */
-#define OSTREE_VERSION (2022.7)
+#define OSTREE_VERSION (2023.6)
 
 /**
  * OSTREE_VERSION_S:
@@ -60,7 +60,7 @@
  *
  * Since: 2017.4
  */
-#define OSTREE_VERSION_S "2022.7"
+#define OSTREE_VERSION_S "2023.6"
 
 #define OSTREE_ENCODE_VERSION(year,release) \
         ((year) << 16 | (release))
@@ -99,5 +99,5 @@
  * Since: 2019.3
  */
 #ifndef __GI_SCANNER__
-#define OSTREE_BUILT_FEATURES "libsoup gpgme ex-fsverity libarchive selinux libmount systemd release p2p"
+#define OSTREE_BUILT_FEATURES "inode64 libcurl libsoup gpgme composefs ex-fsverity libarchive selinux openssl sign-ed25519 libmount systemd release p2p"
 #endif
