@@ -29,16 +29,12 @@ static gboolean
 is_notfound (GError *error)
 {
   return g_error_matches (error, G_KEY_FILE_ERROR, G_KEY_FILE_ERROR_KEY_NOT_FOUND)
-          || g_error_matches (error, G_KEY_FILE_ERROR, G_KEY_FILE_ERROR_GROUP_NOT_FOUND);
+         || g_error_matches (error, G_KEY_FILE_ERROR, G_KEY_FILE_ERROR_GROUP_NOT_FOUND);
 }
 
 gboolean
-ot_keyfile_get_boolean_with_default (GKeyFile      *keyfile,
-                                     const char    *section,
-                                     const char    *value,
-                                     gboolean       default_value,
-                                     gboolean      *out_bool,
-                                     GError       **error)
+ot_keyfile_get_boolean_with_default (GKeyFile *keyfile, const char *section, const char *value,
+                                     gboolean default_value, gboolean *out_bool, GError **error)
 {
   g_return_val_if_fail (keyfile != NULL, FALSE);
   g_return_val_if_fail (section != NULL, FALSE);
@@ -65,12 +61,52 @@ ot_keyfile_get_boolean_with_default (GKeyFile      *keyfile,
 }
 
 gboolean
-ot_keyfile_get_value_with_default (GKeyFile      *keyfile,
-                                   const char    *section,
-                                   const char    *value,
-                                   const char    *default_value,
-                                   char         **out_value,
-                                   GError       **error)
+ot_keyfile_get_tristate_with_default (GKeyFile *keyfile, const char *section, const char *value,
+                                      OtTristate default_value, OtTristate *out_tri, GError **error)
+{
+  g_return_val_if_fail (keyfile != NULL, FALSE);
+  g_return_val_if_fail (section != NULL, FALSE);
+  g_return_val_if_fail (value != NULL, FALSE);
+
+  GError *temp_error = NULL;
+  g_autofree char *ret_value = g_key_file_get_value (keyfile, section, value, &temp_error);
+  if (temp_error)
+    {
+      if (is_notfound (temp_error))
+        {
+          g_clear_error (&temp_error);
+          g_assert (ret_value == NULL);
+          *out_tri = default_value;
+          return TRUE;
+        }
+
+      g_propagate_error (error, temp_error);
+      return FALSE;
+    }
+
+  ret_value = g_strstrip (ret_value);
+
+  if (strcmp (ret_value, "yes") == 0 || strcmp (ret_value, "true") == 0
+      || strcmp (ret_value, "1") == 0)
+    *out_tri = OT_TRISTATE_YES;
+  else if (strcmp (ret_value, "no") == 0 || strcmp (ret_value, "false") == 0
+           || strcmp (ret_value, "0") == 0)
+    *out_tri = OT_TRISTATE_NO;
+  else if (strcmp (ret_value, "maybe") == 0)
+    *out_tri = OT_TRISTATE_MAYBE;
+  else
+    {
+      g_set_error (error, G_KEY_FILE_ERROR, G_KEY_FILE_ERROR_INVALID_VALUE,
+                   "Invalid tri-state value: %s", ret_value);
+      return FALSE;
+    }
+
+  return TRUE;
+}
+
+gboolean
+ot_keyfile_get_value_with_default (GKeyFile *keyfile, const char *section, const char *value,
+                                   const char *default_value, char **out_value, GError **error)
 {
   g_return_val_if_fail (keyfile != NULL, FALSE);
   g_return_val_if_fail (section != NULL, FALSE);
@@ -93,17 +129,14 @@ ot_keyfile_get_value_with_default (GKeyFile      *keyfile,
         }
     }
 
-  ot_transfer_out_value(out_value, &ret_value);
+  ot_transfer_out_value (out_value, &ret_value);
   return TRUE;
 }
 
 gboolean
-ot_keyfile_get_value_with_default_group_optional (GKeyFile      *keyfile,
-                                                  const char    *section,
-                                                  const char    *value,
-                                                  const char    *default_value,
-                                                  char         **out_value,
-                                                  GError       **error)
+ot_keyfile_get_value_with_default_group_optional (GKeyFile *keyfile, const char *section,
+                                                  const char *value, const char *default_value,
+                                                  char **out_value, GError **error)
 {
   g_return_val_if_fail (keyfile != NULL, FALSE);
   g_return_val_if_fail (section != NULL, FALSE);
@@ -111,7 +144,8 @@ ot_keyfile_get_value_with_default_group_optional (GKeyFile      *keyfile,
 
   GError *local_error = NULL;
   g_autofree char *ret_value = NULL;
-  if (!ot_keyfile_get_value_with_default (keyfile, section, value, default_value, &ret_value, &local_error))
+  if (!ot_keyfile_get_value_with_default (keyfile, section, value, default_value, &ret_value,
+                                          &local_error))
     {
       if (g_error_matches (local_error, G_KEY_FILE_ERROR, G_KEY_FILE_ERROR_GROUP_NOT_FOUND))
         {
@@ -125,7 +159,7 @@ ot_keyfile_get_value_with_default_group_optional (GKeyFile      *keyfile,
         }
     }
 
-  ot_transfer_out_value(out_value, &ret_value);
+  ot_transfer_out_value (out_value, &ret_value);
   return TRUE;
 }
 
@@ -133,27 +167,23 @@ ot_keyfile_get_value_with_default_group_optional (GKeyFile      *keyfile,
  * zero or one of the separators and none of the others, read the
  * string as a NULL-terminated array out_value.  If the value string
  * contains multiple of the separators, give an error.
- * 
+ *
  * Returns TRUE on success, FALSE on error. */
 gboolean
-ot_keyfile_get_string_list_with_separator_choice (GKeyFile      *keyfile,
-                                                  const char    *section,
-                                                  const char    *key,
-                                                  const char    *separators,
-                                                  char        ***out_value,
-                                                  GError       **error)
+ot_keyfile_get_string_list_with_separator_choice (GKeyFile *keyfile, const char *section,
+                                                  const char *key, const char *separators,
+                                                  char ***out_value, GError **error)
 {
   g_return_val_if_fail (keyfile != NULL, FALSE);
   g_return_val_if_fail (section != NULL, FALSE);
   g_return_val_if_fail (key != NULL, FALSE);
   g_return_val_if_fail (separators != NULL, FALSE);
 
-  g_autofree char  *value_str = NULL;
-  if (!ot_keyfile_get_value_with_default (keyfile, section, key, NULL,
-                                          &value_str, error))
+  g_autofree char *value_str = NULL;
+  if (!ot_keyfile_get_value_with_default (keyfile, section, key, NULL, &value_str, error))
     return FALSE;
 
-  g_auto(GStrv) value_list = NULL;
+  g_auto (GStrv) value_list = NULL;
   if (value_str)
     {
       gchar sep = '\0';
@@ -175,8 +205,8 @@ ot_keyfile_get_string_list_with_separator_choice (GKeyFile      *keyfile,
         }
       else if (sep_count == 1)
         {
-          if (!ot_keyfile_get_string_list_with_default (keyfile, section, key,
-                                                        sep, NULL, &value_list, error))
+          if (!ot_keyfile_get_string_list_with_default (keyfile, section, key, sep, NULL,
+                                                        &value_list, error))
             return FALSE;
         }
       else
@@ -190,15 +220,11 @@ ot_keyfile_get_string_list_with_separator_choice (GKeyFile      *keyfile,
 }
 
 gboolean
-ot_keyfile_get_string_list_with_default (GKeyFile      *keyfile,
-                                         const char    *section,
-                                         const char    *key,
-                                         char           separator,
-                                         char         **default_value,
-                                         char        ***out_value,
-                                         GError       **error)
+ot_keyfile_get_string_list_with_default (GKeyFile *keyfile, const char *section, const char *key,
+                                         char separator, char **default_value, char ***out_value,
+                                         GError **error)
 {
-  g_autoptr(GError) temp_error = NULL;
+  g_autoptr (GError) temp_error = NULL;
 
   g_return_val_if_fail (keyfile != NULL, FALSE);
   g_return_val_if_fail (section != NULL, FALSE);
@@ -206,8 +232,7 @@ ot_keyfile_get_string_list_with_default (GKeyFile      *keyfile,
 
   g_key_file_set_list_separator (keyfile, separator);
 
-  g_auto(GStrv) ret_value = g_key_file_get_string_list (keyfile, section,
-                                                        key, NULL, &temp_error);
+  g_auto (GStrv) ret_value = g_key_file_get_string_list (keyfile, section, key, NULL, &temp_error);
 
   if (temp_error)
     {
@@ -228,11 +253,9 @@ ot_keyfile_get_string_list_with_default (GKeyFile      *keyfile,
 }
 
 gboolean
-ot_keyfile_copy_group (GKeyFile   *source_keyfile,
-                       GKeyFile   *target_keyfile,
-                       const char *group_name)
+ot_keyfile_copy_group (GKeyFile *source_keyfile, GKeyFile *target_keyfile, const char *group_name)
 {
-  g_auto(GStrv) keys = NULL;
+  g_auto (GStrv) keys = NULL;
   gsize length, ii;
   gboolean ret = FALSE;
 
@@ -255,6 +278,6 @@ ot_keyfile_copy_group (GKeyFile   *source_keyfile,
 
   ret = TRUE;
 
- out:
+out:
   return ret;
 }
