@@ -17,45 +17,39 @@
 
 #include "config.h"
 
-#include <string.h>
 #include <glib-unix.h>
+#include <string.h>
 
-#include "ot-main.h"
-#include "ot-admin-instutil-builtins.h"
 #include "ostree-cmd-private.h"
+#include "ot-admin-instutil-builtins.h"
+#include "ot-main.h"
 
 #include "otutil.h"
 
-static GOptionEntry options[] = {
-  { NULL }
-};
+static GOptionEntry options[] = { { NULL } };
 
 gboolean
-ot_admin_instutil_builtin_grub2_generate (int argc, char **argv, OstreeCommandInvocation *invocation, GCancellable *cancellable, GError **error)
+ot_admin_instutil_builtin_grub2_generate (int argc, char **argv,
+                                          OstreeCommandInvocation *invocation,
+                                          GCancellable *cancellable, GError **error)
 {
-  gboolean ret = FALSE;
-  guint bootversion;
-  g_autoptr(GOptionContext) context = NULL;
-  g_autoptr(OstreeSysroot) sysroot = NULL;
-
-  context = g_option_context_new ("[BOOTVERSION]");
 
+  g_autoptr (GOptionContext) context = g_option_context_new ("[BOOTVERSION]");
+  g_autoptr (OstreeSysroot) sysroot = NULL;
   if (!ostree_admin_option_context_parse (context, options, &argc, &argv,
-                                          OSTREE_ADMIN_BUILTIN_FLAG_SUPERUSER | OSTREE_ADMIN_BUILTIN_FLAG_UNLOCKED,
+                                          OSTREE_ADMIN_BUILTIN_FLAG_SUPERUSER
+                                              | OSTREE_ADMIN_BUILTIN_FLAG_UNLOCKED,
                                           invocation, &sysroot, cancellable, error))
-    goto out;
+    return FALSE;
 
+  guint bootversion;
   if (argc >= 2)
     {
-      bootversion = (guint) g_ascii_strtoull (argv[1], NULL, 10);
+      bootversion = (guint)g_ascii_strtoull (argv[1], NULL, 10);
       if (!(bootversion == 0 || bootversion == 1))
-        {
-          g_set_error (error, G_IO_ERROR, G_IO_ERROR_FAILED,
-                       "Invalid bootversion: %u", bootversion);
-      goto out;
-        }
+        return glnx_throw (error, "Invalid bootversion: %u", bootversion);
     }
-  else 
+  else
     {
       const char *bootversion_env = g_getenv ("_OSTREE_GRUB2_BOOTVERSION");
       if (bootversion_env)
@@ -65,10 +59,6 @@ ot_admin_instutil_builtin_grub2_generate (int argc, char **argv, OstreeCommandIn
       g_assert (bootversion == 0 || bootversion == 1);
     }
 
-  if (!ostree_cmd__private__()->ostree_generate_grub2_config (sysroot, bootversion, 1, cancellable, error))
-    goto out;
-
-  ret = TRUE;
- out:
-  return ret;
+  return ostree_cmd__private__ ()->ostree_generate_grub2_config (sysroot, bootversion, 1,
+                                                                 cancellable, error);
 }
