@@ -14,18 +14,16 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this library. If not, see <https://www.gnu.org/licenses/>.
  *
  * Author: Stef Walter <stefw@redhat.com>
  */
 
 #include "config.h"
 
-#include "ot-main.h"
-#include "ot-builtins.h"
 #include "ostree.h"
+#include "ot-builtins.h"
+#include "ot-main.h"
 #include "otutil.h"
 
 /* ATTENTION:
@@ -33,20 +31,15 @@
  * man page (man/ostree-reset.xml) when changing the option list.
  */
 
-static GOptionEntry options[] = {
-  { NULL }
-};
+static GOptionEntry options[] = { { NULL } };
 
 gboolean
-ostree_builtin_reset (int           argc,
-                      char        **argv,
-                      OstreeCommandInvocation *invocation,
-                      GCancellable *cancellable,
-                      GError      **error)
+ostree_builtin_reset (int argc, char **argv, OstreeCommandInvocation *invocation,
+                      GCancellable *cancellable, GError **error)
 {
-  g_autoptr(GOptionContext) context = NULL;
-  g_autoptr(OstreeRepo) repo = NULL;
-  g_autoptr(GHashTable) known_refs = NULL;
+  g_autoptr (GOptionContext) context = NULL;
+  g_autoptr (OstreeRepo) repo = NULL;
+  g_autoptr (GHashTable) known_refs = NULL;
   gboolean ret = FALSE;
   const char *ref;
   const char *target = NULL;
@@ -55,7 +48,8 @@ ostree_builtin_reset (int           argc,
   /* FIXME: Add support for collection–refs. */
   context = g_option_context_new ("REF COMMIT");
 
-  if (!ostree_option_context_parse (context, options, &argc, &argv, invocation, &repo, cancellable, error))
+  if (!ostree_option_context_parse (context, options, &argc, &argv, invocation, &repo, cancellable,
+                                    error))
     goto out;
 
   if (!ostree_ensure_repo_writable (repo, error))
@@ -90,7 +84,7 @@ ostree_builtin_reset (int           argc,
     goto out;
 
   ret = TRUE;
- out:
+out:
   if (repo)
     ostree_repo_abort_transaction (repo, cancellable, NULL);
   return ret;
