@@ -15,18 +15,16 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this library. If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
 
 #include "otutil.h"
 
+#include "ostree-repo-private.h"
 #include "ot-main.h"
 #include "ot-remote-builtins.h"
-#include "ostree-repo-private.h"
 #include "ot-remote-cookie-util.h"
 
 /* ATTENTION:
@@ -34,18 +32,17 @@
  * man page (man/ostree-remote.xml) when changing the option list.
  */
 
-static GOptionEntry option_entries[] = {
-  { NULL }
-};
+static GOptionEntry option_entries[] = { { NULL } };
 
 gboolean
-ot_remote_builtin_list_cookies (int argc, char **argv, OstreeCommandInvocation *invocation, GCancellable *cancellable, GError **error)
+ot_remote_builtin_list_cookies (int argc, char **argv, OstreeCommandInvocation *invocation,
+                                GCancellable *cancellable, GError **error)
 {
-  g_autoptr(OstreeRepo) repo = NULL;
-  g_autoptr(GOptionContext) context = g_option_context_new ("NAME");
+  g_autoptr (OstreeRepo) repo = NULL;
+  g_autoptr (GOptionContext) context = g_option_context_new ("NAME");
 
-  if (!ostree_option_context_parse (context, option_entries, &argc, &argv,
-                                    invocation, &repo, cancellable, error))
+  if (!ostree_option_context_parse (context, option_entries, &argc, &argv, invocation, &repo,
+                                    cancellable, error))
     return FALSE;
 
   if (argc < 2)
