@@ -21,29 +21,26 @@
 
 #include "config.h"
 
-#include <string.h>
-#include <stdio.h>
+#include <err.h>
+#include <errno.h>
+#include <fcntl.h>
 #include <stdarg.h>
 #include <stdbool.h>
 #include <stdint.h>
-#include <sys/param.h>
-#include <sys/mount.h>
-#include <sys/statvfs.h>
-#include <fcntl.h>
+#include <stdio.h>
 #include <stdlib.h>
-#include <unistd.h>
+#include <string.h>
+#include <sys/mount.h>
+#include <sys/param.h>
 #include <sys/stat.h>
-#include <err.h>
-#include <errno.h>
-
-#include <glib.h>
+#include <sys/statvfs.h>
+#include <unistd.h>
 
 #include "ostree-mount-util.h"
-#include "glnx-backport-autocleanups.h"
+#include "otcore.h"
 
 static void
-do_remount (const char *target,
-            bool        writable)
+do_remount (const char *target, bool writable)
 {
   struct stat stbuf;
   if (lstat (target, &stbuf) < 0)
@@ -70,7 +67,7 @@ do_remount (const char *target,
       /* Also ignore EINVAL - if the target isn't a mountpoint
        * already, then assume things are OK.
        */
-      if (errno != EINVAL)  
+      if (errno != EINVAL)
         err (EXIT_FAILURE, "failed to remount(%s) %s", writable ? "rw" : "ro", target);
       else
         return;
@@ -80,12 +77,38 @@ do_remount (const char *target,
 }
 
 int
-main(int argc, char *argv[])
+main (int argc, char *argv[])
 {
-  /* When systemd is in use this is normally created via the generator, but
-   * we ensure it's created here as well for redundancy.
-   */
-  touch_run_ostree ();
+  g_autoptr (GError) error = NULL;
+  g_autoptr (GVariant) ostree_run_metadata_v = NULL;
+  {
+    glnx_autofd int fd = open (OTCORE_RUN_BOOTED, O_RDONLY | O_CLOEXEC);
+    if (fd < 0)
+      {
+        /* We really expect that nowadays that everything is done in the initramfs,
+         * but historically we created this file here, so we'll continue to do be
+         * sure here it exists.  This code should be removed at some point though.
+         */
+        if (errno == ENOENT)
+          {
+            int subfd = open (OTCORE_RUN_BOOTED, O_EXCL | O_CREAT | O_WRONLY | O_NOCTTY | O_CLOEXEC,
+                              0640);
+            if (subfd != -1)
+              (void)close (subfd);
+          }
+        else
+          {
+            err (EXIT_FAILURE, "failed to open %s", OTCORE_RUN_BOOTED);
+          }
+      }
+    else
+      {
+        if (!ot_variant_read_fd (fd, 0, G_VARIANT_TYPE_VARDICT, TRUE, &ostree_run_metadata_v,
+                                 &error))
+          errx (EXIT_FAILURE, "failed to read %s: %s", OTCORE_RUN_BOOTED, error->message);
+      }
+  }
+  g_autoptr (GVariantDict) ostree_run_metadata = g_variant_dict_new (ostree_run_metadata_v);
 
   /* The /sysroot mount needs to be private to avoid having a mount for e.g. /var/cache
    * also propagate to /sysroot/ostree/deploy/$stateroot/var/cache
@@ -96,7 +119,11 @@ main(int argc, char *argv[])
   if (mount ("none", "/sysroot", NULL, MS_REC | MS_PRIVATE, NULL) < 0)
     perror ("warning: While remounting /sysroot MS_PRIVATE");
 
-  if (path_is_on_readonly_fs ("/"))
+  gboolean root_is_composefs = FALSE;
+  g_variant_dict_lookup (ostree_run_metadata, OTCORE_RUN_BOOTED_KEY_COMPOSEFS, "b",
+                         &root_is_composefs);
+
+  if (path_is_on_readonly_fs ("/") && !root_is_composefs)
     {
       /* If / isn't writable, don't do any remounts; we don't want
        * to clear the readonly flag in that case.
@@ -107,7 +134,9 @@ main(int argc, char *argv[])
   /* Handle remounting /sysroot; if it's explicitly marked as read-only (opt in)
    * then ensure it's readonly, otherwise mount writable, the same as /
    */
-  bool sysroot_configured_readonly = unlink (_OSTREE_SYSROOT_READONLY_STAMP) == 0;
+  gboolean sysroot_configured_readonly = FALSE;
+  g_variant_dict_lookup (ostree_run_metadata, OTCORE_RUN_BOOTED_KEY_SYSROOT_RO, "b",
+                         &sysroot_configured_readonly);
   do_remount ("/sysroot", !sysroot_configured_readonly);
 
   /* And also make sure to make /etc rw again. We make this conditional on
@@ -115,16 +144,15 @@ main(int argc, char *argv[])
   if (sysroot_configured_readonly)
     do_remount ("/etc", true);
 
-  /* If /var was created as as an OSTree default bind mount (instead of being a separate filesystem)
-    * then remounting the root mount read-only also remounted it.
-    * So just like /etc, we need to make it read-write by default.
-    * If it was a separate filesystem, we expect it to be writable anyways,
-    * so it doesn't hurt to remount it if so.
-    *
-    * And if we started out with a writable system root, then we need
-    * to ensure that the /var bind mount created by the systemd generator
-    * is writable too.
-    */
+  /* If /var was created as as an OSTree default bind mount (instead of being a separate
+   * filesystem) then remounting the root mount read-only also remounted it. So just like /etc, we
+   * need to make it read-write by default. If it was a separate filesystem, we expect it to be
+   * writable anyways, so it doesn't hurt to remount it if so.
+   *
+   * And if we started out with a writable system root, then we need
+   * to ensure that the /var bind mount created by the systemd generator
+   * is writable too.
+   */
   do_remount ("/var", true);
 
   exit (EXIT_SUCCESS);
