@@ -32,6 +32,9 @@ else
 fi
 . ${test_srcdir}/libtest-core.sh
 
+# Make sure /sbin/capsh etc. are in our PATH even if non-root
+PATH="$PATH:/usr/sbin:/sbin"
+
 # Array of expressions to execute when exiting. Each expression should
 # be a single string (quoting if necessary) that will be eval'd. To add
 # a command to run on exit, append to the libtest_exit_cmds array like
@@ -177,18 +180,9 @@ if test -n "${OT_TESTS_VALGRIND:-}"; then
     CMD_PREFIX="env G_SLICE=always-malloc OSTREE_SUPPRESS_SYNCFS=1 valgrind -q --error-exitcode=1 --leak-check=full --num-callers=30 --suppressions=${test_srcdir}/glib.supp --suppressions=${test_srcdir}/ostree.supp"
 fi
 
-if test -n "${OSTREE_UNINSTALLED:-}"; then
-    OSTREE_HTTPD=${OSTREE_UNINSTALLED}/ostree-trivial-httpd
-else
-    # trivial-httpd is now in $libexecdir by default, which we don't
-    # know at this point. Fortunately, libtest.sh is also in
-    # $libexecdir, so make an educated guess. If it's not found, assume
-    # it's still runnable as "ostree trivial-httpd".
-    if [ -x "${test_srcdir}/../../libostree/ostree-trivial-httpd" ]; then
-        OSTREE_HTTPD="${CMD_PREFIX} ${test_srcdir}/../../libostree/ostree-trivial-httpd"
-    else
-        OSTREE_HTTPD="${CMD_PREFIX} ostree trivial-httpd"
-    fi
+OSTREE_HTTPD="${G_TEST_BUILDDIR}/ostree-trivial-httpd"
+if ! [ -x "${OSTREE_HTTPD}" ]; then
+    fatal "Failed to find ${OSTREE_HTTPD}"
 fi
 
 files_are_hardlinked() {
@@ -500,7 +494,7 @@ EOF
     if test -n "${OSTREE_NO_XATTRS:-}"; then
         echo -e 'disable-xattrs=true\n' >> sysroot/ostree/repo/config
     fi
-    ${CMD_PREFIX} ostree admin os-init testos
+    ${CMD_PREFIX} ostree admin stateroot-init testos
 
     case $bootmode in
         "syslinux")
